#! /usr/bin/env python
# MainMenu screen for the SimTraffic
# Author: Jonathan Danaparamita
# Version: SimTraffic ZFR, CSE 403 Spring 2009

import pygame

class MainMenu():
    def __init__(self, screen, bgcolor=(255,255,255)):
        self.screen = screen
        self.running = False
        self.value = None         # Remains unused in ZFR

        #Banner
        self.title = pygame.image.load("../media/title.jpg")

        #Buttons
        self.startgame = pygame.image.load("../media/startgame.jpg").convert()
        self.about = pygame.image.load("../media/about.jpg").convert()
        self.quit = pygame.image.load("../media/quit.jpg").convert()

        #Background color
        self.bgcolor = bgcolor

        
    def run(self):
        clock = pygame.time.Clock()

        #Dimensions of title
        titlewidth = self.title.get_width()
        titleheight = self.title.get_height()
        
        #Dimensions of buttons
        buttonwidth = self.startgame.get_width()
        buttonheight = self.startgame.get_height()

        #Dimensions of screen
        screenwidth = self.screen.get_width()
        screenheight = self.screen.get_height()

        #Mouse Position
        x = y = 0

        #Positions of title and buttons (not fixed. changed mainly based on screensize)
        xTitle = (screenwidth-titlewidth)/2
        yTitle = 0
        xStartgame = xAbout = xQuit = (screenwidth-buttonwidth)/2
        yStartgame = 2*(screenheight)/3
        yAbout = yStartgame + 50
        yQuit = yAbout + 50

        #The thickness of highlighting line
        line_thickness = buttonheight/10

        running = 1
        while running:
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    running = 0
                elif event.type == pygame.MOUSEMOTION:
                    x, y = event.pos
                elif event.type == pygame.MOUSEBUTTONDOWN: 
                        x, y = event.pos
                        if (x >= xStartgame and x <= xStartgame+buttonwidth and y >= yQuit and y <= yQuit+buttonheight):
                                running = 0
                
            self.screen.fill(self.bgcolor)

            #Highlights hovered buttons
            if (x >= xStartgame and x <= xStartgame+buttonwidth):
                if (y >= yStartgame and y <= yStartgame+buttonheight):
                    pygame.draw.line(self.screen,(0,0,0),(0,yStartgame+buttonheight/2-1),(screenwidth,yStartgame+buttonheight/2-1),line_thickness)
                elif (y >= yAbout and y <= yAbout+buttonheight):
                    pygame.draw.line(self.screen,(0,0,0),(0,yAbout+buttonheight/2-1),(screenwidth,yAbout+buttonheight/2-1),line_thickness)
                elif (y >= yQuit and y <= yQuit+buttonheight):
                    pygame.draw.line(self.screen,(0,0,0),(0,yQuit+buttonheight/2-1),(screenwidth,yQuit+buttonheight/2-1),line_thickness)
                                
            self.screen.blit(self.title, (xTitle,yTitle))
            self.screen.blit(self.startgame,(xStartgame,yStartgame))
            self.screen.blit(self.about,(xAbout,yAbout))
            self.screen.blit(self.quit,(xQuit,yQuit))
            
            pygame.display.flip()
            clock.tick(20)

